isNotNullOrEmpty property
bool
get
isNotNullOrEmpty
Checks if the string is not null and not empty.
Implementation
bool get isNotNullOrEmpty => this != null && this!.isNotEmpty;
Checks if the string is not null and not empty.
bool get isNotNullOrEmpty => this != null && this!.isNotEmpty;